@@ -2,11 +2,23 @@ sd_section("Build trajectories",
   "Methods for building trajectory objects.",
   c(
     "create_trajectory",
+    "batch",
     "branch",
+    "clone",
+    "join",
+    "leave",
     "release",
+    "release_selected",
+    "renege_in",
+    "renege_abort",
     "rollback",
     "seize",
+    "seize_selected",
+    "select",
+    "separate",
     "set_attribute",
+    "set_prioritization",
+    "synchronize",
     "timeout"
   )
 )
@@ -40,8 +52,10 @@ sd_section("Manage simulation environments",
   "Methods for getting information about simulation components.",
   c(
     "get_capacity",
+    "set_capacity",
     "get_n_generated",
     "get_queue_size",
+    "set_queue_size",
     "get_queue_count",
     "get_server_count",
     "now",
@@ -62,7 +76,6 @@ sd_section("Convenience functions",
   "Helper methods for generators and resources.",
   c(
     "at",
-    "every",
     "from",
     "from_to",
     "schedule",
